searchData={"items":[{"type":"module","title":"HPAX","doc":"Support for the HPACK header compression algorithm.\n\nThis module provides support for the HPACK header compression algorithm used mainly in HTTP/2.","ref":"HPAX.html"},{"type":"module","title":"Encoding and decoding contexts - HPAX","doc":"The HPACK algorithm requires both\n\n  * an encoding context on the encoder side\n  * a decoding context on the decoder side\n\nThese contexts are semantically different but structurally the same. In HPACK they are\nimplemented as **HPACK tables**. This library uses the name \"tables\" everywhere internally\n\nHPACK tables can be created through the `new/1` function.","ref":"HPAX.html#module-encoding-and-decoding-contexts"},{"type":"function","title":"HPAX.decode/2","doc":"Decodes a header block fragment (HBF) through a given table.\n\nIf decoding is successful, this function returns a `{:ok, headers, updated_table}` tuple where\n`headers` is a list of decoded headers, and `updated_table` is the updated table. If there's\nan error in decoding, this function returns `{:error, reason}`.","ref":"HPAX.html#decode/2"},{"type":"function","title":"Examples - HPAX.decode/2","doc":"decoding_context = HPAX.new(1000)\n    hbf = get_hbf_from_somewhere()\n    HPAX.decode(hbf, decoding_context)\n    #=> {:ok, [{\":method\", \"GET\"}], decoding_context}","ref":"HPAX.html#decode/2-examples"},{"type":"function","title":"HPAX.encode/2","doc":"Encodes a list of headers through the given table.\n\nReturns a two-element tuple where the first element is a binary representing the encoded headers\nand the second element is an updated table.","ref":"HPAX.html#encode/2"},{"type":"function","title":"Examples - HPAX.encode/2","doc":"headers = [{:store, \":authority\", \"https://example.com\"}]\n    encoding_context = HPAX.new(1000)\n    HPAX.encode(headers, encoding_context)\n    #=> {iodata, updated_encoding_context}","ref":"HPAX.html#encode/2-examples"},{"type":"function","title":"HPAX.encode/3","doc":"Encodes a list of headers through the given table, applying the same `action` to all of them.\n\nThis function is the similar to `encode/2`, but `headers` are `{name, value}` tuples instead,\nand the same `action` is applied to all headers.","ref":"HPAX.html#encode/3"},{"type":"function","title":"Examples - HPAX.encode/3","doc":"headers = [{\":authority\", \"https://example.com\"}]\n    encoding_context = HPAX.new(1000)\n    HPAX.encode(:store, headers, encoding_context)\n    #=> {iodata, updated_encoding_context}","ref":"HPAX.html#encode/3-examples"},{"type":"function","title":"HPAX.new/1","doc":"Creates a new HPACK table.\n\nSame as `new/2` with default options.","ref":"HPAX.html#new/1"},{"type":"function","title":"HPAX.new/2","doc":"Create a new HPACK table that can be used as encoding or decoding context.\n\nSee the \"Encoding and decoding contexts\" section in the module documentation.\n\n`max_table_size` is the maximum table size (in bytes) for the newly created table.","ref":"HPAX.html#new/2"},{"type":"function","title":"Options - HPAX.new/2","doc":"This function accepts the following `options`:\n\n  * `:huffman_encoding` - (since 0.2.0) `:always` or `:never`. If `:always`,\n    then HPAX will always encode headers using Huffman encoding. If `:never`,\n    HPAX will not use any Huffman encoding. Defaults to `:never`.","ref":"HPAX.html#new/2-options"},{"type":"function","title":"Examples - HPAX.new/2","doc":"encoding_context = HPAX.new(4096)","ref":"HPAX.html#new/2-examples"},{"type":"function","title":"HPAX.resize/2","doc":"Resizes the given table to the given maximum size.\n\nThis is intended for use where the overlying protocol has signaled a change to the table's\nmaximum size, such as when an HTTP/2 `SETTINGS` frame is received.\n\nIf the indicated size is less than the table's current size, entries\nwill be evicted as needed to fit within the specified size, and the table's\nmaximum size will be decreased to the specified value. A flag will also be\nset which will enqueue a \"dynamic table size update\" command to be prefixed\nto the next block encoded with this table, per\n[RFC9113§4.3.1](https://www.rfc-editor.org/rfc/rfc9113.html#section-4.3.1).\n\nIf the indicated size is greater than or equal to the table's current max size, no entries are evicted\nand the table's maximum size changes to the specified value.","ref":"HPAX.html#resize/2"},{"type":"function","title":"Examples - HPAX.resize/2","doc":"decoding_context = HPAX.new(4096)\n    HPAX.resize(decoding_context, 8192)","ref":"HPAX.html#resize/2-examples"},{"type":"type","title":"HPAX.header_name/0","doc":"An HPACK header name.","ref":"HPAX.html#t:header_name/0"},{"type":"type","title":"HPAX.header_value/0","doc":"An HPACK header value.","ref":"HPAX.html#t:header_value/0"},{"type":"opaque","title":"HPAX.table/0","doc":"An HPACK table.\n\nThis can be used for encoding or decoding.","ref":"HPAX.html#t:table/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}